==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Polyline/DrawPolyline/ts/DrawPolyline_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>DrawPolyline</name>
    <message>
        <location filename="../DrawPolyline.js" line="+69"/>
        <source>First vertex</source>
        <translation>最初の頂点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next vertex</source>
        <translation>次の頂点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>close</source>
        <translation>close</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>undo</source>
        <translation>undo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>redo</source>
        <translation>redo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>arc</source>
        <translation>arc</translation>
    </message>
    <message>
        <location filename="../DrawPolyline.ui" line="+23"/>
        <source>Close polyline</source>
        <translation>ポリラインを閉じる</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>,, C</source>
        <translation>,, C</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translation>前のセグメントを取り消し</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation>,, U</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation>セグメントをやり直し</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation>,, R</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Arc with radius:</source>
        <translation>半径を指定の弧:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>,, A</source>
        <translation>,, A</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sweep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Restrict length or angle</source>
        <translation>長さや角度を制限</translation>
    </message>
    <message>
        <source>Arc segment with radius:</source>
        <translation type="vanished">半径を指定の弧:</translation>
    </message>
    <message>
        <location filename="../DrawPolylineInit.js" line="+2"/>
        <source>&amp;Draw Polyline</source>
        <translation>&amp;D ポリライン描画</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw polyline with line and arc segments</source>
        <translation>線分と弧でポリラインを描画</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Polyline/DrawPolyline/ts/DrawPolyline_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DrawPolyline</name>
    <message>
        <location filename="../DrawPolyline.js" line="+70"/>
        <source>First vertex</source>
        <translation>最初の頂点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next vertex</source>
        <translation>次の頂点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>close</source>
        <translation>close</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>undo</source>
        <translation>undo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>redo</source>
        <translation>redo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>arc</source>
        <translation>arc</translation>
    </message>
    <message>
        <location filename="../DrawPolyline.ui" line="+23"/>
        <source>Close polyline</source>
        <translation>ポリラインを閉じる</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>,, C</source>
        <translation>,, C</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translation>前のセグメントを取り消し</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation>,, U</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation>セグメントをやり直し</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation>,, R</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Arc with radius:</source>
        <translation>半径を指定の弧:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>,, A</source>
        <translation>,, A</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sweep</source>
        <translation>曲線</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Restrict length or angle</source>
        <translation>長さや角度を制限</translation>
    </message>
    <message>
        <source>Arc segment with radius:</source>
        <translation type="vanished">半径を指定の弧:</translation>
    </message>
    <message>
        <location filename="../DrawPolylineInit.js" line="+2"/>
        <source>&amp;Draw Polyline</source>
        <translation>&amp;D ポリライン描画</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw polyline with line and arc segments</source>
        <translation>線分と弧でポリラインを描画</translation>
    </message>
</context>
</TS>
